# Web

Web-related functionality for haolib applications.

## Overview

The web module provides web-specific functionality such as idempotency support.

## Components

- **Idempotency**: Idempotency middleware and storage
